-------
-- Lotke - Volterra model for predator-prey models
--- 

hares_HBC = {30, 47.2, 70.2, 77.4, 36.3, 20.6, 18.1, 21.4,  22, 25.4, 27.1, 40.3,   57, 76.6, 52.3, 19.5, 11.2,  7.6, 14.6, 16.2, 24.7}
lynx_HBC =  { 4,  6.1,  9.8, 35.2, 59.4, 41.7,   19,   13, 8.3,  9.1,  7.4,    8, 12.3, 19.5, 45.7, 51.1, 29.7, 15.8,  9.7, 10.1,  8.6} 



function createObserverChart (terrame_object, plotLabel)
	chart = Observer {
		subject     = terrame_object,
		attributes  = plotLabel.attributes,
		curveLabels = plotLabel.attributes,
		title       = plotLabel.title,
		xLabel      = plotLabel.xLabel,
		yLabel      = plotLabel.yLabel,
		type = "chart"
	}
end

function createPlot (model)

	createObserverChart (model.stocks, model.plotLabels)
	model.stocks:notify(0) 

end
------------------
function createTimer (model)

	model.timer = Timer {
		Event{time = 1, period = 1, action = function(e)
			changes(model)
			model.stocks.hares_HBC = hares_HBC [e:getTime()]
			model.stocks.lynx_HBC  = lynx_HBC  [e:getTime()]		
			model.stocks:notify(e:getTime()) 
		end}
	}
end
-------------------

function changes (model)

	model.stocks.hares = model.stocks.hares 
						 + model.params.preyGrowth*model.stocks.hares
						 - model.params.preyDeathByPred*model.stocks.hares*model.stocks.lynx

	model.stocks.lynx = model.stocks.lynx
						- model.params.predDeath*model.stocks.lynx
						+ model.params.predGrowthByKills*model.stocks.hares*model.stocks.lynx					 

end

-----------------

function run (model, time)
	model.timer:execute (time)
end

-----------
function OscillationModel(model)

	-- create Plot
	createPlot (model)

	-- timer
	createTimer (model)

	return model
end
---------
model =  OscillationModel {
	plotLabels = {
		  attributes = {"lynx", "hares", "lynx_HBC", "hares_HBC"}, 
	      title      = {"Hares and lynx"}, 
	      xLabel     = {"months"}, 
	      yLabel     = {"animals"}
	},
	stocks        = Cell { lynx = 4, hares = 35, lynx_HBC = 4, hares_HBC = 35 },
	params        = { preyGrowth = ?,  -- 0.3 to 0.6
					  preyDeathByPred = ?, -- 0.015 to 0.030
					  predDeath = ?, -- 0.90 to 0.98
					  predGrowthByKills = ? -- 0.020 to 0.030
	              	}
}

-----
run (model, 20) 


