-------
-- Lotke - Volterra model for predator-prey models
--- 

function createObserverChart (terrame_object, plotLabel)
	chart = Observer {
		subject     = terrame_object,
		attributes  = plotLabel.attributes,
		curveLabels = plotLabel.curveLabels,
		title       = plotLabel.title,
		xLabel      = plotLabel.xLabel,
		yLabel      = plotLabel.yLabel,
		xAxis       = plotLabel.xAxis,
		type = "chart"
	}
end

function createPlot (model)

	createObserverChart (model.animals, model.plotLabels)
	model.animals:notify(0) 

end
------------------
function createTimer (model)

	model.timer = Timer {

		Event{time = 1, period = 200, priority  = 0, action = function(ev)
			 model.animals:notify(ev:getTime())
		end},

		Event{time = 1, period = 1, priority  = 1, action = function(ev)
			changes(model)
			model.animals:notify(ev:getTime())
		end},
	}
end
-------------------

function changes (model)

	model.animals.rabbits = model.animals.rabbits 
						 + model.params.preyGrowth*model.animals.rabbits
						 - model.params.preyDeathByPred*model.animals.rabbits*model.animals.wolves

	model.animals.wolves = model.animals.wolves
						- model.params.predDeath*model.animals.wolves
						+ model.params.predGrowthByKills*model.animals.rabbits*model.animals.wolves					 

end

-----------------

function run (model, time)
	model.timer:execute (time)
end

-----------
function OscillationModel(model)

	-- create Plot
	createPlot (model)

	-- timer
	createTimer (model)

	return model
end
---------
model =  OscillationModel {
	plotLabels = {
		  attributes  = {"wolves" },
	      title      = "Rabbits and Wolves",
	      curveLabels = {"PhaseSpace"},
	      xAxis      = "rabbits",
	      xLabel     = "rabbits", 
	      yLabel     = "wolves"
	},
	animals        = Cell { wolves = 40, rabbits = 1000 },
	params        = { preyGrowth = 0.08, 
					  preyDeathByPred = 0.001, 
					  predDeath = 0.02, 
					  predGrowthByKills = 0.00002
	              	}
}

-----




run (model, 1400) 


